#
# spec file for package hivex
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2011 Michal Hrusecky <mhrusecky@novell.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define with_perl 1
%define with_python 1

Name:           hivex
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  pkg-config
Requires:       perl(Getopt::Long)
Requires:       perl(Pod::Usage)
Requires:       perl(Win::Hivex)
Requires:       perl(Win::Hivex::Regedit)
Recommends:     %name-lang
Url:            http://libguestfs.org/hivex.3.html
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Summary:        Windows "Registry Hive" extraction library
License:        LGPL-2.1 and GPL-2.0
Group:          System/Filesystems
Version:        1.3.11
Release:        2.5
Source:         http://libguestfs.org/download/hivex/%name-%version.tar.gz
Source2:        http://libguestfs.org/download/hivex/%name-%version.tar.gz.sig
Source3:        %name.keyring

%description
Hivex is a library for extracting the contents of Windows "Registry
Hive" files. It is designed to be secure against buggy or malicious
registry files.

%package devel
Summary:        Development files for hivex
Group:          Development/Languages/C and C++
Requires:       libhivex0 = %version

%description devel
Development files for hivex. Hivex is a Windows Registry Hive extraction
library.

%package -n libhivex0
Summary:        Windows Registry Hive extraction library
Group:          System/Filesystems

%description -n libhivex0
Hivex is a Windows Registry Hive extraction library.

%if %with_perl
%package -n perl-Win-Hivex
Summary:        Perl bindings for hivex
Group:          System/Filesystems
Requires:       perl = %perl_version
%if 0%{?suse_version} < 1140
BuildRequires:  perl-macros
%endif
BuildRequires:  perl(ExtUtils::MakeMaker)
BuildRequires:  perl(IO::Stringy)
BuildRequires:  perl(Test::More)
%perl_requires

%description -n perl-Win-Hivex
This subpackage contains the Perl bindings for hivex.
Hivex is a Windows Registry Hive extraction library.

%endif

%if %with_python
%package -n python-hivex
%define pyver %(python -c "import sys; print sys.version[:3]")
BuildRequires:  python
BuildRequires:  python-devel
Summary:        Python bindings for libhivex
Group:          System/Filesystems

%description -n python-hivex
This subpackage contains the Python bindings for hivex.
Hivex is a Windows Registry Hive extraction library.
%endif

%lang_package

%prep
%setup -q

%build
if python --version && ! pkg-config python
then
	export PYTHON_LIBS="-lpython`python -c 'import distutils.sysconfig; print (distutils.sysconfig.get_python_version ());'`"
	export PYTHON_CFLAGS="-I`python -c 'import distutils.sysconfig; print (distutils.sysconfig.get_python_inc ());'`"
	export PYTHON_EXT_SUFFIX=.so
fi
%configure --disable-static
# 'INSTALLDIRS' ensures that perl libs are installed in the vendor dir instead of the site dir
make \
	INSTALLDIRS=vendor \
	LD_RUN_PATH= \
	%{?_smp_mflags}

%install
%make_install
%perl_process_packlist
%perl_gen_filelist
# the macro above packages everything, here only the perl files are desrired
grep "%perl_vendorarch/" %name.files | tee t
mv t %name.files
#
rm -f %buildroot/%_libdir/*.{l,}a
touch %name.lang
%find_lang %name

%post -n libhivex0 -p /sbin/ldconfig
%postun -n libhivex0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc README
%_bindir/*
%_mandir/*/*

%files devel
%defattr(-,root,root)
%_libdir/pkgconfig/*
%_includedir/*
%_libdir/*.so

%files -n libhivex0
%defattr(-,root,root)
%_libdir/*.so.*

%if %with_python
%files -n python-hivex
%defattr(-,root,root)
%_libdir/python%pyver/site-packages/*
%endif

%if %with_perl
%post -n perl-Win-Hivex -p /sbin/ldconfig

%postun -n perl-Win-Hivex -p /sbin/ldconfig

%files -n perl-Win-Hivex -f %name.files
%defattr(-,root,root)
%endif
#

%files lang -f %name.lang

%changelog
* Mon Mar 16 2015 jengelh@inai.de
- Retrieve and verify GPG signature. Resolve some orthographic and
  typographic errors in descriptions. Make descriptions more
  similar.
- Run spec-beautifier
* Sun Jan 18 2015 p.drouand@gmail.com
- Update to version 3.11
  * extra-tests: Add trivial fuzz tester
  * handle: Check that pages do not extend beyond the end of the file.
- Use download Url as source
- Split out translation files into lang subpackage
- Recommend hivex-lang
* Tue May 13 2014 ohering@suse.de
- update to version 1.3.10
  many bugfixes, see included changelog for details
* Mon Aug  5 2013 cfarrell@suse.com
- license update: LGPL-2.1 and GPL-2.0
  README states license is LGPL-2.1 (only) and LICENSE confirms. There is a
  significant number of GPL-2.0 files in test and examples
* Wed Jul 31 2013 ohering@suse.de
- update to version 1.3.8
* Sun Feb 24 2013 ohering@suse.de
- BuildRequire: perl-macros only in sles11 builds to fix build in 11.4
* Wed Nov  7 2012 ohering@suse.de
- update to version 1.3.7
* Sat Sep  1 2012 ohering@suse.de
- move python bindings to python-hivex
* Sat Sep  1 2012 ohering@suse.de
- enable perl bindings, package them in perl-Win-Hivex
* Tue Jul  3 2012 ohering@suse.de
- update to version 1.3.6
* Mon Jul  2 2012 ohering@suse.de
- workaround buggy python detection by adding python to BuildRequires
- fix filelist to build on sles11
* Tue Sep 27 2011 mhrusecky@suse.cz
- initial hivex package (version 1.3.1)
